缠中说禅图解分析示范

> 整理一些原文图解分析示范，持续更新。等我的技术熟练了，也会考虑放一些最新的图解分析示范。

# 博客原文图解分析示范

## 2007-09 至 2008-01

> 显示，第一个绿箭头的那一笔，没有发生笔破坏，那必然要回落去完成线段的走势，这是理论上100%保证的。而92这一处，出现线段破坏，但该线段不能拉回85处，那么这就构成了85-88这1分钟中枢的第三类卖点，后面的继续下跌也是理论100%保证的。93处，标准的线段类背驰，这就意味着92这1分钟第三类卖点，将出现中枢扩展，至少形成一个1分钟中枢，这也是理论100%保证的。也就是说88-93的下跌已经完成，后面必然有一个针对这下跌的反弹。后面的演化，都如教科书般标准，学过本ID理论的，都知道这一切都可以当下判断，无须事后分析。那么，现在后面的走势如何，很简单，84-93这个1分钟的走势类型离开76-85这个5分钟中枢后，就要看一个1分钟的走势类型的反抽能否出现回到79这一点，也就是5265点之上。不行，就构成这5分钟中枢的第三类卖点，后面至少要扩展成为30分钟中枢，最恶劣的，就是一个5分钟级别的下跌。今天在93点按理论要求进去的，以及昨天没按理论要求走的，都要关注这第三类买卖点是否成立，如果不成立，那大盘就继续中枢震荡，那简直是本ID理论的天堂。（2007-09-12 15:42 本ID理论的现场教科书演示）

> 这就如同下棋，只看一步，肯定高手不了，能知道上午的跳水，其实是去形成92-95的第三类买点，这就不错，为什么？因为一般都关注5265点了，5265点按理论，如期成为大盘的阻力，由此产生的回落，当然可以短差一把，但由于在96时，95-96与93-94的力度对比并没有明显的类背驰，而且一旦回落形成下面1分钟的第三类买点，反而成为反弹继续的动力， 能看出这一点，就比光看5265点要更进一步了。后来，96到99形成一个新的1分钟中枢，那么这个对76-85这5分钟中枢，86-93的1分钟走势类型离开，93开始的1分钟走势类型的反抽就一目了然了，这意味着，后来，突破该中枢继续上行，突破5265点，第三类卖点不成立，76-85开始的中枢震荡依旧。显然，目前这个93开始的1分钟走势并没有结束，96-99是第一个中枢，如果是盘整走势，那么99开始的向上就要和93-96的形成盘整背驰，如果不形成，这走势就强了，理论上大盘完全可以再创新高。但探讨这个问题没意义，关键是看这盘整背驰是否形成。不过，对于96-99这1分钟中枢，其第三类买点还没有形成，因此，比上面的盘整背驰还要急迫的，就是要确认这第三类买点，否则，最多只能是这1分钟中枢的震荡，然后由此产生96-99的第三类卖点，转而下跌也是符合理论要求的。 所以，明天的技术走势极为简单，最强的，就是开盘后能形成96-99的1分钟中枢的第三类买点，然后继续上攻，这时候必须关注其盘整背驰问题，一旦出现，该怎样操作，就不用说了。弱的，就是不能形成第三类买点，然后继续中枢震荡，最弱的当然就是形成第三类卖点，然后再次大幅下跌。因此，明天的走势，只要看好这几点，一切都在当下把握中。注意，正确的操作，就是93背驰进入后，现在一直持有着，或者你有技术条件，96-97的震荡的可以对冲一把的，回补或换股后，现在应该是持有状态。最坏的情况，就是今晚突然有巨大消息，这样明天一开，确定96-99的第三类卖点成立，就手起刀落。当然，这种情况，一百天也碰不到一次，所以一般情况，就可以耐心等待真正卖点的出现。卖点出现干什么，就不用说了。
> 按照正确的划分，大盘的走势比错误划分中显示出更强的趋势，也就是93开始的回抽，是一个标准的线段类上涨，连1分钟中枢还没构成。当然，明天开盘一跌破96，1分钟中枢就形成，而如果不破，97开始的线段依旧延伸，后面的线段回抽不破96，那这线段类上涨就延伸出3个类中枢了，那当然是超强的表现。明天，就要注意这线段类上涨的结束位置，然后下来的线段调整，必然形成1分钟中枢，其后走势，都与该1分钟中枢的演化相关，这太简单，就不要详细说了。
> （2007-09-13 16:00 有些钱不是适合每个人赚的）

> 显然，本周如期出现周K线顶分型，而且制造了一次绝妙的短线机会。那么，下周就在于，能否破坏这周K线顶分型。看过本ID课程的都知道，周K线顶分型出现后，如果在5周均线处得到支持不有效跌破，那么，该顶分型只制造一个小级别调整，不会出现周K线上的笔调整那样的大级别调整。 因此，下周的走势十分明确，下面就看5周均线的支持度能否制造该顶分型的破坏。
> 小级别图上，今天的走势在昨天已经明确说过，就是形成1分钟中枢，然后根据该中枢的震荡情况决定行情的发展。今天的走势，其实就干了这样一件事情。下周一的走势最简单，就是98到101这1分钟中枢究竟是先有第三类买点还是先有第三类卖点，如果是前者，那么这个1分钟的向上走势将延续，破坏周线顶分型的可能性极大。如果出现后者，那么二次探底就不可避免，5周均线将继续受到考验。
> 这两天的图形，完美地演绎着本ID的理论，从中可以看出，一个线段上涨如何演化出一个1分钟走势类型，后面，继续看这走势类型如何生长，到最终的完成。如果你真明白本ID的理论，看行情的走势，就如同听一朵花的开放，见一朵花的芬芳，嗅一朵花的美丽，一切都在当下中灿烂。(2007-09-14 15:33 下周焦点：能否破坏周K线顶分型)

> 今天早上的上攻(134)，一没有突破昨天的第三类卖点(132)，二反而是形成标准的顶分型第三根K线的上冲，不管你相信不相信本ID的理论，反正后面的走势，如教科书般。现在的走势十分简单，一个1分钟的走势正离开前面那5分钟中枢，这1分钟走势什么时候能完成，就看后面的走势了，而完成以后的回拉才是最重要的，是否能形成第三类卖点，这才是最近走势的关键，如果形成，那这两天，最多只能算田亮的1米板，后面是表演3米还是10米的，这对于观众，其实反而已经不重要了。(2007-09-26 15:56 可以不相信月饼，但一定要相信月亮)

> 132的第三类卖点后，到137的1分钟完成，走势极端标准完美。有兴趣的可以量一下130-131，与136-137，长度基本相等，而力度上，加一下下面对应的柱子面积就知道该干什么。 而到了138，就知道这5分钟的第三类卖点肯定没戏了，就算137没反应，139就提供了一个反应的机会。
> 当然，站在中枢震荡的角度，并不需要预测后面能走多高，让市场告诉你。 而今天的走势，强悍到连一个线段都没破坏过，那该干什么还不是很清楚的事情？节后的走势，十分清楚，就是首先要完成这个1分钟的离开，从目前的情况看，这1分钟的离开走势是首先是线段的类上涨的可能性太大了，除非有特别的大消息，当线段类上涨结束后，必然形成1分钟中枢，该中枢后，1分钟的走势无论是盘整还是上涨，等1分钟走势完成后，关键是看反抽能否形成前面5分钟中枢的第三类买点了，如果形成，大盘将继续攻击上行，否则就继续向30分钟中枢的震荡陷进去。(2007-09-28 15:51 资金乘胜追击，破圆顶兵临3/4线)

> 针对189-192的1分钟中枢，195是第三类卖点，但对于191开始的线段类下跌，194-195是第二个类中枢，所以后面的跌破，力度不够，出现明显背驰，然后就必然要在这个位置出现一个新的1分钟中枢。 下面的走势很简单，这个新的一分钟中枢是否继续向下延伸出新的1分钟下跌走势，也就是这1分钟中枢是否有第三类卖点。而从大的方面看，这次反弹的调整，级别将至少向5分钟级别扩展。当然，操作上第一个中枢的第三类卖点在该级别中是最后的走人机会，后面的都没意义了，也就是说，对于这次调整的逃避，191是第一类卖点，因为前面线段类上涨走势出现类背驰，而193是第二类卖点，因为站在线段的角度，就是第二类卖点，而站在189-192的1分钟中枢震荡的角度，任何的次级别离开，都将先构成卖点，然后再考虑是否回跌形成第三类买点的回补机会，这是中枢震荡的操作方法。195以后，针对这个调整来说，任何的卖出，都是太晚了，这意味着随时面临下跌走势的结束。很多人喜欢在第二个中枢才考虑第三类卖点，那是晚之又晚，所以经常卖了，就被反转夹空，那是一点都不奇怪的。 当然，很有可能卖了以后继续延续下跌，但这已经是一个概率问题，而不是一个能被理论100%保证的技术问题了。(2007-11-02 15:25 调整形态保持，震荡级别加大)

> 上面给出了6004下来的分段，请仔细研究，里面用绿箭头把三个1分钟中枢的第三类卖点都给标记出来了。按照本ID的理论，最晚的逃命点195处，从第1个绿箭头开始的所谓第三类卖点，其实都没什么意义，这里，只是显示，第三类卖点后，市场是可以多么狠。按本ID的理论，从195逃命的，在214才真正开始值得考虑是否回补。 当然，前提是你的操作可以接受1分钟级别的，如果是5分钟以上级别的操作，那还是继续睡觉吧。214，从191开始的1分钟下跌走势的底背驰，对应着三重的区间套定位，最后一重是213-214之间的线段内部笔之间的定位， 其中的精确性，教科书一般，关键是你能真明白，并且能当下去把握。（2007-11-12 15:28 1000点小康跌幅胜利完成）

> 回到大盘本身，第二个1分钟中枢如期到来，但只要这1分钟不能出现第三类买点，不能有效重新站上4778点，后面的震荡依然少不了，但这将提供更多的短线获利机会。大盘的走势：最好的，就是直接形成这1分钟中枢第三类买点，然后形成线段或1分钟式的上涨，重新回到5100点上，这走势的前提就是那第三类买点。次好的，就是在这里形成5分钟中枢后再出现第三类买点，这里有两种途径，一种是9次级别的震荡扩展出5分钟，一种是先1分钟的第三类卖点后底背驰上来再出来5分钟。这里就构成了N次必然的短线机会。最坏的，就是在这里5分钟后出现其第三类卖点，这甚至构成一个5分钟下跌的第一个中枢，这样，后面的走势就比前面还要恶劣。
> 由于现在的走势有如下复杂的演化可能，所以操作上必须严格根据图形来，一旦出现5分钟不能重站住4778点的情况，就一定要注意后面可能向最坏情况演化的任何苗头。(2008-01-23 15:16 如期反弹后的4778点压力)

> 今天，在昨天所说的4778点受到压制产生震荡。4778点，在技术上十分重要，因为这是前期低点，能否出现上去站住，决定了这次下跌的性质与最终完成形式。说句直接的，就是一条多空抉择线。从日线上，今天早上的下跌反而是为了最终构成日的底分型，这是一个买点。但后面的问题更为关键，就是这底分型能否延伸为笔，还是最终被5日线压制夭折。由于5日线已经下移到4815点，明天大概也就到4778点附近了，因此，这个问题和上面一个问题是同解的，还是4778点能否突破站住的问题。技术上，如果你把今天13点40分前后当成所谓的1分钟第三类买点，那么至少你需要补习两个知识点，一个是线段分类中的第二种情况的处理问题，第二是如果线段延伸9段后，需要考虑的就不是1分钟中枢，而是5分钟中枢的问题，这里的次级别变成1分钟走势类型了。(2008-01-24 15:17 4778点，多空抉择线。)

> 注意，由于目前日线的形态不好，所以，就算这笔延伸出来，后面肯定还有向下的笔来确认的，这个向上笔结束的位置很重要：
> 一、如果在4818点上下就结束，那么就是最弱的，后面就不亮晶晶了，改10X10米晶晶亮了。
> 二、如果4918上下结束，这还有较大可能回头形成诸如双底、头肩底之类的形态。
> 三、冲上5000点后再结束，那么形态上稍微好转了，后面只要回头幅度不大，多头又可以重新架设炮台，再次进攻了。
> 因此，这个向上笔的结束位置很重要，市场最终的走势，走出来自然就当下辨别了，无须预测。
> 这两天的走势，对底分型的具体操作是一个很好的锻炼。依据底分型的买卖，不是今天才买，而是昨天探底不创新低时就买，当然，如果你技术好一点，你可以确认这个探低是震荡性质的。注意，分型的操作，不是分型已经确认形成才操作，那时候已经是“已病”状态，就太晚了，这一点必须明确。例如，昨天买了以后，今天走势继续保持（1，1）形态，所以可以不管，等到出现顶分型时再处理。当然，说起来简单，实际操作，又少不了诸多的练习才能把握。(2008-01-25 15:17 下周补缺，多头别无选择)

> 大盘今天开盘就选择“ 一、如果在4818点上下就结束，那么就是最弱的，后面就不亮晶晶了，改10X10米晶晶亮了。”一个线段就下来了400点，然后是一个线段的反弹，这反弹只要不能重新回来原来震荡区间，就有逐步扩展成5分钟第三类卖点的风险。关于目前的情况，前面已经很明确地说过，最坏的情况就是在4778点下形成5分钟下跌的第一个中枢，一旦这种情况出现，后面的下跌可能更加惨烈。那么次坏的情况，就是这5分钟中枢是盘整类型中的，最终扩展成30分钟的。这种情况，不过依然是震荡局面，没什么大不了的。最好的情况，就是这5分钟又震回去，最后还震出第三类买点来，但你的思维里千万不能被这种最好的走势完全占据，这样会蒙住你自己的眼睛。(2008-01-28 15:20 580989完美地达到理论要求的第一目标)

# 背驰段

> MACD是辅助，首先要把走势给分清楚，否则又怎么知道是哪段和哪段比？这次上来这一段，可以先看成是5分钟级别的背驰段，如果背驰成立，就至少重新跌回4600点上下中枢，也最迟在周一前就有结果。也就是说，这个背驰段是否成立的结果。(2007-08-09 16:21:19)

> 请好好研究一下000938的图，看看昨天的顶分型多么标准，而今天17.59的1分钟底背驰又是多么经典，力度比较请看5分钟图。这两者的差价有多少？

> 600078，请好好研究15、5、1之类的图，看看那区间套是多么教科书。还是那句话，跌的时候，要想买点，涨的时候，要想卖点，这才是搞股票的，否则是被股票搞的。(2007-09-24 15:26 震荡前行、多空齐杀)

> 今天的回落，刚好触及140-143的1分钟中枢的震荡区域，但没有触及到中枢区域，因此，如果这下来的线段明天不继续延续，将构成一个类第三类买点，然后上去，再继续。 这里有一个微妙的地方，今天留下这个线段不走完，就给明天的运作留下回旋的空间。一旦明天没有特别的东西，那么就继续上攻，继续吸精大法，毕竟多头的能量还在，让多头更快更强更高地套住，以后的杀跌动力才足够，这就举得越高，跌得越惨；如果明天就有足够的政策配合，那么这线段就直接杀下去，让那1分钟中枢扩展开来。(2007-10-10 15:27 空头，熊刀小试)

> 来本ID这里，关键是学东西。如果太计较自己有没有这股票，是不是赚了，那你的水平永远提不高。还是用本ID的股票为例子，一个最令人深恶痛绝的股票：600636。你是否在里面赚钱并不重要，关键是你能否在这经典走势中学到点什么。看看这经典的走势：一个ABC的下跌，其中的B段在120天线受阻，然后大力挖井后回手在120天突破回试确认，然后迅速回到井的上沿13元附近，一个超完美的井。 后面干什么？就是要确认这井的上沿能否站住的问题了，这都是最标准的走势。如果对这类似的走势烂熟于胸，难道你还不能自如地应付类似的走势？(2008-01-04 15:12 多头，有了冲动就要喊)

> 短线上，5522点下来的这个线段的类下跌过程十分技术化，两个类中枢也十分明显，下面就是这类下跌的类背驰问题了，一旦出现，就是一次有力度的反弹，关键是这反弹能否突破第二个类中枢的牵制，如果不行，那么缺口的回补就有困难，所以这才是技术上的关键。 日线上，昨天的顶分型后，现在延伸成笔的可能太大了，只要明天有新底就基本确定，所以，稳健的角度，可以等底分型才会有真正的站稳可能，所以这个类背驰能否最终制造出底分型，就是进一步考察的关键。(2008-01-16 15:17 大盘又见亮晶晶)

> 别小看了最基础的分段技术，5522点下来，近500点，就是一个线段的类下跌，你明白了，就主动了，就享受了。为什么？最猛烈的中枢移动中，往往就是一个线段的类趋势，所谓的单边跌势或涨势，就是这玩意，明白了，你说你能不爽吗？今天一大早的急拉，只构成了笔，没有破坏下跌段，如果明白这点，操作就太简单了，因为你绝对不会错过下午那明显的类背驰。但注意，由于这个类背驰的不是在两个类中枢间的，而是单纯一线段中出现的，所以，这个回拉如果不能重新站住5209点，那么后面还要二次探底。 本周开始时已经说了，春节前要出点情况，就是这周了，后面，就要逐步营造点和谐的气氛，但在营造和谐之前，首先要营造的是恐怖，没有恐怖，把不坚定分子彻底清洗，哪来和谐啊？(2008-01-17 15:14 不会享受大震荡的人股票就没入门)

> 按纯技术的分析，从5522点下来，按照本ID的理论，线段下跌结束后，中阴形成1分钟中枢，那么，最坏的情况，就是这中枢是1分钟下跌的第一个中枢，如果这样，这跌势还早着，至少要等到这1分钟下跌背驰才完。还有就是先扩展才5分钟中枢，因为30分钟级别的震荡，最大的级别只能是5分钟的，因此一旦那5分钟形成，最坏的情况，就是那是5分钟下跌的第一个中枢。 无论后面的中枢是1分钟还是5分钟的，都要走出第三类买点才算真正摆脱下跌的压力。而实际上，由于今天下午已经把那1分钟的中枢的第三类卖点（在什么位置和时间，一个简单的题目，如果当时不能正确马上给出的，都要补课）给制造出来，所以，下面最好的情况，就是扩展成5分钟中枢，而且，1分钟下跌形成的机会绝对不小。从理论上有了这么明确的分类，后面的操作就很简单了。如果你不想烦，就看日的底分型的形成时再说。如果你特爱好换股短线，那么，就根据这个中枢的演化去安排具体的操作，事情就是这么简单，唯一有点复杂的是，你操作的是具体股票，指数是指数，股票是股票，从来就不经常是一回事情。所以，多关心你自己的股票，你的股票池的具体走势。例如，就算今天的走势，依然有股票继续新高。(2008-01-21 15:18 又被暗算的多头尚能饭否？)

> 大盘的走势，和昨天晚上课程说的是一致的，就是等待第一个机会，线段下跌的类背驰，显然，在今天早上的反弹后，第二个类中枢已经形成，所以，这个第一个小机会已经在即，这构成短线的一个反弹。这反弹，将至少构造一个1分钟中枢，由于在5100上下已经有1中枢，因此这构成1分钟下跌的第二中枢的可能性极大，除非能线段式地一下重回5100点，否则，只有这种情况。1分钟中枢后，就是扩展为5分钟或出现1分钟下跌背驰两种情况，而这次反弹，在最坏的情况下，构成对4778点跌破的回抽，然后再次探底，因此，能否重新站住4778点，这是短线最关键的问题。(2008-01-22 15:12 超短线反弹在即)

> 下面最大的机会，就是6124点下来30分钟走势类型结束后的向上30分钟走势类型，这机会在酝酿中，也就是在中阴阶段。但那30分钟的向上类型，最坏的情况，就是一个盘整，并不一定走出上涨类型，这是必须明确的。如果是盘整，就在这上下搞出一个日的中枢，然后就面临6124下来的日走势类型的第一个中枢，后面无论延伸出下跌或盘整，都是完全可能的，如果是下跌，那当然恐怖无比，比这几个月都要恐怖。所以，3月前后，对中线走势极为关键，要继续全面富裕还是怎么着，就看着办了。(2008-02-14 15:25 后三日是技术上最关键时刻)

> 卖出总在向上的过程中，也就是总在红柱子时。在上次刚出红柱子时，本ID已经明确说过了，一旦上冲没力，一定要先走，因此在4695点就算你没看出那5分钟的盘整背驰，里面还包括一个1分钟盘整背驰的区间套，那么，浦发的消息也已经足以让你走人了。至于那些还要问绿柱子出来再走是不是太晚的人，永远不会懂得什么叫节奏。不懂得节奏，那就继续被市场调戏吧。(2008-02-25 15:23 新基金难敌乱增发)

> 当然，从超短线的角度，昨天已明确指出1分钟底背驰出现后的机会。今天的走势，简直是超级教科书，下午一开盘的第三类卖点，然后再破底，在2点半形成最后的底背驰，如此教科书的走势，如果都不能看明白并操作，那么唯一的办法就是继续读书。由于1分钟背驰后，最低的回升幅度就是回到最后一个中枢里，所以，明天的关键就是这升幅能否扩大。日线上，今天已经有底分型的雏形，明天只要不破底并比今天最高位高，底分型就成立，后面就是是否延伸为笔的问题，所以，技术上已经初步具备上冲的形态。(2008-02-26 15:14 无技术含量救市已审美疲劳)

> 今天的走势，在4331点上下形成第一个1分钟的中枢，因此，后面的走势，就是这中枢的演化，一旦这中枢能形成第三类买点，那么，构成上涨并重新回到原来5分钟震荡的几率就极大了。操作上，就很简单，你根本不需要慌忙抛出，因为你可以根据这中枢的演化再做决定。当然，如果你的胆子特小，那最稳健的做法，就是今天下午开盘后那线段类背驰先抛出一半，为什么？因为线段类背驰后必然形成1分钟中枢，这表明你不想全仓参加这1分钟的震荡，等其后走势确认再说。当然，对于一般心态好的，其实没必要如此，1分钟的震荡你都受不了，那还怎么搞股票。不过，对于操作水平有一定的，其实也可以利用那线段的类背驰，进行换股操作，这是效率最高的玩法，不过这对水平要求更高，并不是每个人都可以达到的。(2008-02-27 15:19 4391点决定短线走势)

# 日线分型辅助

> 000938，今天提供了一个日线底分型的买入机会，就算你不关心这股票，那也请从纯技术角度，好好研究其图形。(2007-09-13 16:00 有些钱不是适合每个人赚的)